@@ -33,8 +33,8 @@
 use warnings;
 use strict;
 
-our $VERSION = '3.020'; # VERSION
-my $LAST_UPDATE = '3.010'; # manually update whenever code is changed
+our $VERSION = '3.022'; # VERSION
+my $LAST_UPDATE = '3.021'; # manually update whenever code is changed
 
 use Math::Trig;
 use List::Util qw(min max);
@@ -56,8 +56,8 @@ my $compress = 'none';
 
 my $pdf = PDF::Builder->new(-compress => $compress);
 my ($page, $grfx, $text); # objects for page, graphics, text
-my (@base, @styles, @points, $i, $lw, $angle, @npts);
-my (@cellLoc, @cellSize, $font, $width, $d1, $d2, $d3, $d4);
+my (@points, $i);
+my ($font);
 my @axisOffset = (5, 5); # clear the edge of the cell
 
 my $db = 4;  # debug level
